using System;
using System.Drawing;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using AddinExpress.PP;
using PowerPoint = Microsoft.Office.Interop.PowerPoint;
using System.Linq;
using System.Collections.Generic;

namespace ScheduledPPT
{
    public partial class SchedulePane : AddinExpress.PP.ADXPowerPointTaskPane
    {
        public SchedulePane()
        {
            InitializeComponent();
        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            ScheduledPPT.AddinModule module = null;
            PowerPoint._Application app = null;
            PowerPoint.DocumentWindow activeWindow = null;
            PowerPoint.View activeView = null;
            PowerPoint.Slide activeSlide = null;
            SlideSchedule slideSchedule = null;

            try
            {
                module = AddinExpress.MSO.ADXAddinModule.CurrentInstance as
                    ScheduledPPT.AddinModule;
                app = (PowerPoint._Application)this.PowerPointAppObj;
                activeWindow = app.ActiveWindow;
                activeView = activeWindow.View;
                activeSlide = (PowerPoint.Slide)activeView.Slide;

                slideSchedule = module.Schedule.FirstOrDefault(
                    s => s.SlideIndex == activeSlide.SlideIndex);
                if (slideSchedule != null)
                {
                    slideSchedule.ShowAt = dateTimePickerStart.Value;
                    slideSchedule.ShowFor = Convert.ToInt32(textBoxMinutes.Text);
                }
                else
                {
                    module.Schedule.Add(new SlideSchedule
                    {
                        SlideIndex = activeSlide.SlideIndex,
                        ShowAt = dateTimePickerStart.Value,
                        ShowFor = Convert.ToInt32(textBoxMinutes.Text)
                    });
                }
                RefreshListView(module.Schedule);
            }
            finally
            {
                if (activeSlide != null)
                    Marshal.ReleaseComObject(activeSlide);
                if (activeView != null)
                    Marshal.ReleaseComObject(activeView);
                if (activeWindow != null)
                    Marshal.ReleaseComObject(activeWindow);
            }
        }

        private void RefreshListView(List<SlideSchedule> schedule)
        {
            lvSchedule.Items.Clear();
            foreach (SlideSchedule slideSchedule in schedule)
            {
                ListViewItem lvItemSlideNr = new ListViewItem(slideSchedule.SlideIndex.ToString());
                ListViewItem.ListViewSubItem lvItemShowAt = new ListViewItem.ListViewSubItem(lvItemSlideNr, slideSchedule.ShowAt.ToShortTimeString());
                ListViewItem.ListViewSubItem lvItemShowFor = new ListViewItem.ListViewSubItem(lvItemSlideNr, slideSchedule.ShowFor.ToString() + " minute(s)");
                lvItemSlideNr.SubItems.Add(lvItemShowAt);
                lvItemSlideNr.SubItems.Add(lvItemShowFor);
                lvSchedule.Items.Add(lvItemSlideNr);
            }
        }
    }
}
